<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../../../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../../../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>モニターの設定</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>設定の保存</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation>名前の変更</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation>適用</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="64"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="67"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="70"/>
        <source>Inverted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="73"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>True</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="77"/>
        <location filename="../../../managesavedsettings.cpp" line="78"/>
        <source>False</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name</source>
        <translation>名前</translation>
    </message>
    <message>
        <location filename="../../../managesavedsettings.cpp" line="140"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
</context>
<context>
    <name>MonitorInfo</name>
    <message>
        <source>Laptop LCD Monitor</source>
        <translation type="vanished">ラップトップ液晶モニター</translation>
    </message>
    <message>
        <source>External VGA Monitor</source>
        <translation type="vanished">外部VGAモニター</translation>
    </message>
    <message>
        <source>VGA Monitor</source>
        <translation type="vanished">VGAモニター</translation>
    </message>
    <message>
        <source>External DVI Monitor</source>
        <translation type="vanished">外部DVIモニター</translation>
    </message>
    <message>
        <source>DVI Monitor</source>
        <translation type="vanished">DVIモニター</translation>
    </message>
    <message>
        <source>TV</source>
        <translation type="vanished">TV</translation>
    </message>
    <message>
        <source>Default Monitor</source>
        <translation type="vanished">デフォルトのモニター</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <source>Dialog</source>
        <translation type="vanished">ダイアログ</translation>
    </message>
    <message>
        <location filename="../../../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>モニターの設定</translation>
    </message>
    <message>
        <source>Quick Options</source>
        <translation type="vanished">クイックオプション</translation>
    </message>
    <message>
        <source>Show the same screen on both laptop LCD and external monitor</source>
        <translation type="vanished">ラップトップ液晶パネルと外部モニターで同じ画面を表示</translation>
    </message>
    <message>
        <source>Extended view</source>
        <translation type="vanished">拡張領域</translation>
    </message>
    <message>
        <source>Turn off laptop LCD and use external monitor only</source>
        <translation type="vanished">ラップトップ液晶画面を無効にし、外部モニターのみ使う</translation>
    </message>
    <message>
        <source>Turn off external monitor and use laptop LCD only</source>
        <translation type="vanished">外部モニターを無効にし、ラップトップ液晶画面のみ使う</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.ui" line="71"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Unify all monitors</source>
        <translation type="vanished">すべてのモニターの表示を共通にする</translation>
    </message>
    <message>
        <source>Monitor Position</source>
        <translation type="vanished">モニターの位置</translation>
    </message>
    <message>
        <source>Primary monitor:</source>
        <translation type="vanished">プライマリーモニター:</translation>
    </message>
    <message>
        <source>Do you want to save changes?</source>
        <translation type="vanished">変更を保存しますか？</translation>
    </message>
    <message>
        <source>Please, check your config before to save.</source>
        <translation type="vanished">保存する前に、設定結果を確認してください</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="111"/>
        <source>Fast Menu</source>
        <translation>ファストメニュー</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="115"/>
        <source>Set position</source>
        <translation>位置の設定</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">エラー</translation>
    </message>
    <message>
        <source>Config can not be saved</source>
        <translation type="vanished">設定を保存することができませんでした</translation>
    </message>
    <message>
        <location filename="../../../monitorsettingsdialog.cpp" line="244"/>
        <source>Advanced settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <source>Turn on</source>
        <translation type="vanished">有効にする</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation>解像度:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation>このディスプレイを有効にする</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation>このディスプレイを優先する</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation>他のディスプレイにこのスクリーンを拡張する</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>高度</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation>リフレッシュレート:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation>回転:</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>情報</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>ディスプレイの情報</translation>
    </message>
    <message>
        <source>Rate:</source>
        <translation type="vanished">リフレッシュレート:</translation>
    </message>
    <message>
        <source>Hz</source>
        <translation type="vanished">Hz</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="vanished">位置:</translation>
    </message>
    <message>
        <source>x:</source>
        <translation type="vanished">X座標:</translation>
    </message>
    <message>
        <source>y:</source>
        <translation type="vanished">Y座標:</translation>
    </message>
    <message>
        <source>Brightness:</source>
        <translation type="vanished">明るさ:</translation>
    </message>
    <message>
        <source>Gamma:</source>
        <translation type="vanished">ガンマ:</translation>
    </message>
    <message>
        <source>:</source>
        <translation type="vanished">:</translation>
    </message>
    <message>
        <source>Backlight:</source>
        <translation type="vanished">バックライト:</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="vanished">自動</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="135"/>
        <source>Name: %1
</source>
        <translation>名前: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="136"/>
        <source>Vendor: %1
</source>
        <translation>ベンダー: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="137"/>
        <source>Serial: %1
</source>
        <translation>シリアル番号: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="138"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>ディスプレイのサイズ: %1cm x %2cm
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="139"/>
        <source>Serial number: %1
</source>
        <translation>シリアル番号: %1
</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="140"/>
        <source>EISA device ID: %1
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="161"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="162"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="163"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="164"/>
        <source>Inverted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../monitorwidget.cpp" line="255"/>
        <source>%1 Hz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Auto</source>
        <translation type="vanished">自動</translation>
    </message>
    <message>
        <source>Monitor Settings</source>
        <translation type="obsolete">モニターの設定</translation>
    </message>
    <message>
        <source>Quick Options</source>
        <translation type="obsolete">クイックオプション</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="obsolete">設定</translation>
    </message>
    <message>
        <location filename="../../../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>保存された設定の管理</translation>
    </message>
</context>
<context>
    <name>QuickOptions</name>
    <message>
        <source>Monitor Settings</source>
        <translation type="obsolete">モニターの設定</translation>
    </message>
    <message>
        <source>Show the same screen on both laptop LCD and external monitor</source>
        <translation type="obsolete">ラップトップ液晶パネルと外部モニターで同じ画面を表示</translation>
    </message>
    <message>
        <source>Extended view</source>
        <translation type="obsolete">拡張領域</translation>
    </message>
    <message>
        <source>Turn off laptop LCD and use external monitor only</source>
        <translation type="obsolete">ラップトップ液晶画面を無効にし、外部モニターのみ使う</translation>
    </message>
    <message>
        <source>Turn off external monitor and use laptop LCD only</source>
        <translation type="obsolete">外部モニターを無効にし、ラップトップ液晶画面のみ使う</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <source>Monitor Settings</source>
        <translation type="obsolete">モニターの設定</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../../../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>設定は変更されました</translation>
    </message>
    <message>
        <location filename="../../../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>この設定で問題ないですか？</translation>
    </message>
    <message>
        <source>%1 second(s) remaining</source>
        <translation type="vanished">残り %1 秒</translation>
    </message>
    <message numerus="yes">
        <location filename="../../../timeoutdialog.cpp" line="62"/>
        <source>%n second(s) remaining</source>
        <translation>
            <numerusform>残り %n 秒</numerusform>
        </translation>
    </message>
</context>
</TS>
